"""Built-in benchmark suites."""

from .refactor_storm import (
    REFACTOR_STORM,
    INSTRUCTION_ADHERENCE_SPEC,
    CODE_QUALITY_SPEC,
)

__all__ = [
    "REFACTOR_STORM",
    "INSTRUCTION_ADHERENCE_SPEC",
    "CODE_QUALITY_SPEC",
]
